@@ -288,10 +288,33 @@ def purge_customer(name):
     with records.Database(url) as db:
         sql = "DELETE FROM customer WHERE name=:name"
         db.query(sql, name=name)
+        LOGS.logger.info("Customer {} information deleted from SI database".format(name))
         sql = "DELETE FROM cdr WHERE customer=:name"
         db.query(sql, name=name)
+        LOGS.logger.info("Customer {} CDRs deleted from SI database".format(name))
         sql = "DELETE FROM fup WHERE customer=:name"
         db.query(sql, name=name)
+        LOGS.logger.info("Customer {} fup history deleted from SI database".format(name))
+    LOGS.logger.info("Customer {} purged from SI database".format(name))
+
+
+def clean_database():
+    """
+    Removes all data in database about customers that are not returned by CRM list
+    """
+    customers_crm = []
+    for product in ["business_access", "business_plus"]:
+        customers = get_customers_crm(product)
+        customers_crm += [customer['ident'] for customer in customers]
+
+    customers_si = get_customers_si()
+    customers_si = [customer['name'] for customer in customers_si]
+
+    customers_common = set(customers_crm) & set(customers_si)
+    remainder_si = [name for name in customers_si if name not in customers_common]
+    for customer in remainder_si:
+        purge_customer(customer)
+    LOGS.logger.info("{} customers were purged from database".format(len(remainder_si)))
 
 
 def record_customer(infos):
